@@ -9,7 +9,7 @@ import argparse
 from plumbum import cli
 import pyperclip
 
-from en_detail.get_detail import get_data, print_basetrans, print_detailtrans
+from dict_tiny.en_detail.get_detail import get_data, print_basetrans, print_detailtrans
 
 APP_DESC = """
 tiny dictionary
@@ -22,7 +22,7 @@ tiny dictionary
 
 class Dict_tiny(cli.Application):
     PROGNAME = "Dict-tiny"
-    VERSION = "0.2"
+    VERSION = "0.2.1"
     DESCRIPTION = "A tiny command-line dictionary that scrapes youdao.com. Just for fun."
 
     moredetail = cli.Flag(["-m", "--more"],
